﻿#pragma strict

/**
 * Lerp Easing/Slerp Easing Test.
 */
public class LerpEasingTest extends MonoBehaviour {
	/**
	 * Slerp / Lerpフラグ。
	 */
	public var slerpFlag:boolean = false;

	/**
	 * 回転フラグ。
	 */
	private var rotFlag:boolean = false;

	/**
	 * 回転開始と終了のQuaternion。
	 */
	private var firstRot:Quaternion;
	private var targetRot:Quaternion;

	/**
	 * Awake.
	 */
	public function Awake():void {
		this.firstRot = this.transform.rotation;
		this.targetRot = this.firstRot * Quaternion.AngleAxis(180, Vector3.up);
	}

	/**
	 * Update.
	 */
	public function Update():void {
		if (this.rotFlag) {
			if (this.slerpFlag)
				this.transform.rotation = Quaternion.Slerp(this.transform.rotation, this.targetRot, Time.deltaTime);
			else
				this.transform.rotation = Quaternion.Lerp(this.transform.rotation, this.targetRot, Time.deltaTime);
		}
	}

	/**
	 * 再生/停止。
	 */
	public function PlayStop():void {
		if (this.rotFlag) {
			this.transform.rotation = this.firstRot;
		}

		this.rotFlag = !this.rotFlag;
	}

	/**
	 * OnGUI.
	 */
	public function OnGUI():void {
		var pos:Vector3 = Camera.main.WorldToScreenPoint(this.transform.position);
		var label:String;

		if (this.rotFlag) {
			label = 'Reset';
		}
		else {
			label = this.slerpFlag ? 'Slerp Easing' : 'Lerp Easing';
		}

		if (GUI.Button(Rect(pos.x - 80, -pos.y + Screen.height + 100, 160, 30), label)) {
			if (label == 'Reset') {
				this.transform.rotation = this.firstRot;
				this.rotFlag = false;
			}
			else {
				this.rotFlag = true;
			}
		}
	}
}