﻿#pragma strict

/**
 * Lerp / Slerp Test.
 */
public class LerpTest extends MonoBehaviour {
	/**
	 * Slerp / Lerpフラグ。
	 */
	public var slerpFlag:boolean = false;

	/**
	 * 回転フラグ。
	 */
	private var rotFlag:boolean = false;

	/**
	 * 回転開始と終了のQuaternion。
	 */
	private var firstRot:Quaternion;
	private var targetRot:Quaternion;

	/**
	 * 経過時間。
	 */
	private var passedTime:float = 0;

	/**
	 * Awake.
	 */
	public function Awake():void {
		this.firstRot = this.transform.rotation;
		this.targetRot = this.firstRot * Quaternion.AngleAxis(180, Vector3.up);
	}

	/**
	 * Update.
	 */
	public function Update():void {
		if (this.rotFlag) {
			this.passedTime += Time.deltaTime;

			if (this.slerpFlag)
				this.transform.rotation = Quaternion.Slerp(this.firstRot, this.targetRot, this.passedTime);
			else
				this.transform.rotation = Quaternion.Lerp(this.firstRot, this.targetRot, this.passedTime);

			if (this.passedTime >= 1) {
				this.transform.rotation = this.firstRot;
				this.passedTime = 0;
				this.rotFlag = false;
			}
		}
	}

	/**
	 * 再生/停止。
	 */
	public function PlayStop():void {
		if (this.rotFlag) {
			this.transform.rotation = this.firstRot;
			this.passedTime = 0;
		}

		this.rotFlag = !this.rotFlag;
	}

	/**
	 * OnGUI.
	 */
	public function OnGUI():void {
		var pos:Vector3 = Camera.main.WorldToScreenPoint(this.transform.position);

		if (GUI.Button(Rect(pos.x - 80, -pos.y + Screen.height + 100, 160, 30), this.slerpFlag ? 'Slerp' : 'Lerp')) {
			this.rotFlag = true;
		}
	}
}